@@ -85,7 +85,7 @@ public:
     {
         MCWorld::instance().addObject(m_this);
 
-        for (auto child : m_children)
+        for (auto && child : m_children)
         {
             MCWorld::instance().addObject(*child);
         }
@@ -95,7 +95,7 @@ public:
     {
         MCWorld::instance().addObject(m_this);
 
-        for (auto child : m_children)
+        for (auto && child : m_children)
         {
             MCWorld::instance().addObject(*child);
         }
@@ -109,7 +109,7 @@ public:
         {
             MCWorld::instance().removeObject(m_this);
 
-            for (auto child : m_children)
+            for (auto && child : m_children)
             {
                 MCWorld::instance().removeObjectNow(*child);
             }
@@ -122,7 +122,7 @@ public:
         {
             MCWorld::instance().removeObjectNow(m_this);
 
-            for (auto child : m_children)
+            for (auto && child : m_children)
             {
                 MCWorld::instance().removeObjectNow(*child);
             }
@@ -536,20 +536,13 @@ public:
         return *m_parent;
     }
 
-    ~Impl()
-    {
-        removeFromWorldNow();
-        deleteContacts();
-    }
-
 private:
     float calculateLinearBalance(const MCVector3dF & force, const MCVector3dF & pos)
     {
         float linearBalance = 1.0f;
         if (shape())
         {
-            const float r = shape()->radius();
-            if (r > 0)
+            if (const float r = shape()->radius(); r > 0)
             {
                 linearBalance = 1.0f - MCMathUtil::distanceFromVector(MCVector2dF(pos - location()), MCVector2dF(force)) / r;
                 linearBalance = linearBalance < 0 ? 0 : linearBalance;
@@ -561,8 +554,7 @@ private:
 
     void checkXBoundariesAndSendEvent(float minX, float maxX)
     {
-        const MCWorld & world = MCWorld::instance();
-        if (minX < world.minX())
+        if (const MCWorld & world = MCWorld::instance(); minX < world.minX())
         {
             MCOutOfBoundariesEvent e(MCOutOfBoundariesEvent::West, m_this);
             m_this.outOfBoundariesEvent(e);
@@ -576,8 +568,7 @@ private:
 
     void checkYBoundariesAndSendEvent(float minY, float maxY)
     {
-        const MCWorld & world = MCWorld::instance();
-        if (minY < world.minY())
+        if (const MCWorld & world = MCWorld::instance(); minY < world.minY())
         {
             MCOutOfBoundariesEvent e(MCOutOfBoundariesEvent::South, m_this);
             m_this.outOfBoundariesEvent(e);
@@ -591,8 +582,7 @@ private:
 
     void checkZBoundariesAndSendEvent()
     {
-        const MCWorld & world = MCWorld::instance();
-        if (m_location.k() < world.minZ())
+        if (const MCWorld & world = MCWorld::instance(); m_location.k() < world.minZ())
         {
             m_physicsComponent->resetZ();
             translate(
@@ -1091,4 +1081,8 @@ MCPhysicsComponent & MCObject::physicsComponent()
     return m_impl->physicsComponent();
 }
 
-MCObject::~MCObject() = default;
+MCObject::~MCObject()
+{
+    MCObject::removeFromWorldNow();
+    deleteContacts();
+}
