@@ -110,20 +110,18 @@ void MCSurfaceObjectRendererLegacy::setBatch(MCRenderLayer::ObjectBatch & batch,
 
 void MCSurfaceObjectRendererLegacy::setAttributePointers()
 {
-    glVertexAttribPointer(MCGLShaderProgram::VAL_Vertex, 3, GL_FLOAT, GL_FALSE,
+    glVertexAttribPointer(static_cast<int>(MCGLShaderProgram::VertexAttributeLocation::Vertex), 3, GL_FLOAT, GL_FALSE,
                           sizeof(MCGLVertex), reinterpret_cast<GLvoid *>(m_vertices.data()));
-    glVertexAttribPointer(MCGLShaderProgram::VAL_Normal, 3, GL_FLOAT, GL_FALSE,
+    glVertexAttribPointer(static_cast<int>(MCGLShaderProgram::VertexAttributeLocation::Normal), 3, GL_FLOAT, GL_FALSE,
                           sizeof(MCGLVertex), reinterpret_cast<GLvoid *>(m_normals.data()));
-    glVertexAttribPointer(MCGLShaderProgram::VAL_TexCoords, 2, GL_FLOAT, GL_FALSE,
+    glVertexAttribPointer(static_cast<int>(MCGLShaderProgram::VertexAttributeLocation::TexCoords), 2, GL_FLOAT, GL_FALSE,
                           sizeof(MCGLTexCoord), reinterpret_cast<GLvoid *>(m_texCoords.data()));
-    glVertexAttribPointer(MCGLShaderProgram::VAL_Color, 4, GL_FLOAT, GL_FALSE,
+    glVertexAttribPointer(static_cast<int>(MCGLShaderProgram::VertexAttributeLocation::Color), 4, GL_FLOAT, GL_FALSE,
                           sizeof(MCGLColor), reinterpret_cast<GLvoid *>(m_colors.data()));
 }
 
 void MCSurfaceObjectRendererLegacy::render()
 {
-    assert(shaderProgram());
-
     shaderProgram()->bind();
     shaderProgram()->bindMaterial(material());
 
@@ -142,8 +140,6 @@ void MCSurfaceObjectRendererLegacy::render()
 
 void MCSurfaceObjectRendererLegacy::renderShadows()
 {
-    assert(shadowShaderProgram());
-
     shadowShaderProgram()->bind();
     shadowShaderProgram()->bindMaterial(material());
 
