@@ -24,18 +24,21 @@ class MCWorldTest : public QObject
     Q_OBJECT
 
 public:
-
     MCWorldTest();
 
 private slots:
 
     void testAddToWorld();
 
+    void testCollisionEvent_RectRect();
+
+    void testCollisionEvent_RectCircle();
+
+    void testCollisionEvent_CircleCircle();
+
     void testInstance();
 
     void testSetDimensions();
 
-    void testSimpleCollision();
-
     void testSleepingObjectRemovalFromIntegration();
 };
