@@ -30,7 +30,7 @@ Intro::Intro()
     m_back->setColor(MCGLColor(1.0f, 1.0f, 1.0f, 1.0f));
 }
 
-void Intro::setDimensions(size_t width, size_t height)
+void Intro::setDimensions(int width, int height)
 {
     OverlayBase::setDimensions(width, height);
 }
@@ -47,7 +47,7 @@ void Intro::render()
     static auto version = QString("v") + VERSION;
     static MCTextureText versionText(version.toStdWString());
     versionText.setGlyphSize(20, height() / 32);
-    versionText.setColor(MCGLColor(0.75f, 0.75f, 0.75f));
+    versionText.setColor({ 0.75f, 0.75f, 0.75f });
     versionText.render(
       versionText.height(m_font),
       versionText.height(m_font), nullptr, m_font, false);
