@@ -20,7 +20,10 @@
 #include <QObject>
 #include <QString>
 #include <QTimer>
+
+#include <chrono>
 #include <memory>
+#include <optional>
 #include <unordered_map>
 #include <vector>
 
@@ -40,158 +43,135 @@ class Race : public AudioSource
     Q_OBJECT
 
 public:
-    //! Constructor.
     Race(Game & game, size_t numCars);
+    virtual ~Race() override;
 
-    //! Destructor.
-    virtual ~Race();
+    using TrackS = std::shared_ptr<Track>;
+    void initialize(TrackS track, size_t lapCount);
 
-    //! Init the race.
-    void init(std::shared_ptr<Track>, size_t lapCount);
+    bool started() const;
 
-    //! Return true, if race has started.
-    bool started();
-
-    //! Get the number of laps.
     size_t lapCount() const;
 
-    //! Add a car to the race.
     void addCar(Car & car);
-
-    //! Removes cars from the race.
     void removeCars();
 
-    //! Get the timing object.
-    Timing & timing();
+    using TimingW = std::weak_ptr<Timing>;
+    TimingW timing() const;
 
     bool checkeredFlagEnabled() const;
 
-    size_t getCurrentTargetNodeIndex(const Car & car) const;
+    size_t getCurrentTargetNodeIndex(size_t carIndex) const;
 
-    //! Get current last car in the race
     Car & getLoser() const;
-
-    //! Get current leading car in the race
     Car & getLeader() const;
 
-    //! Get current position of a car.
-    size_t position(const Car & car) const;
+    size_t position(size_t carIndex) const;
 
 signals:
 
     void finished();
-
     void messageRequested(QString message);
-
     void tiresChanged(const Car & car);
 
+    void lapRecordAchieved(int msec);
+    void raceRecordAchieved(int msec);
+
 public slots:
 
     void start();
 
     void stopEngineSounds();
 
-    void update();
+    void update(std::chrono::milliseconds timeStep);
 
     void pitStop(Car & car);
 
 private:
     void checkForNewBestPosition(const Car & car);
-
     void checkIfCarIsStuck(Car & car);
-
     void checkIfCarIsOffTrack(Car & car);
-
     void checkIfLapIsCompleted(Car & car, const Route & route, size_t currentTargetNodeIndex);
 
     void clearPositions();
-
     void clearRaceFlags();
 
     void createStartGridObjects();
 
     void initCars();
-
     void initTiming();
 
     bool isRaceFinished() const;
 
     void moveCarOntoPreviousCheckPoint(Car & car);
 
-    void setTrack(std::shared_ptr<Track>, size_t lapCount);
+    void setTrack(TrackS track, size_t lapCount);
 
     void translateCarsToStartPositions();
 
     void updateRouteProgress(Car & car);
-
     void updatePositions();
 
     const size_t m_humanPlayerIndex1;
-
     const size_t m_humanPlayerIndex2;
 
     // Position required to unlock a new track
-    const size_t m_unlockLimit;
+    const size_t m_unlockLimit = 6;
 
-    typedef std::vector<Car *> CarVector;
+    using CarVector = std::vector<Car *>;
     CarVector m_cars;
 
     // Used only to keep references to the start grid objects.
     // They are common for all races and created only once.
-    typedef std::vector<MCObjectPtr> StartGridObjectVector;
+    using StartGridObjectVector = std::vector<MCObjectPtr>;
     StartGridObjectVector m_startGridObjects;
 
     // Map from car route progression to car order vector.
     // Tracks the order of the cars in the route.
-    typedef std::unordered_map<size_t, std::vector<size_t>> ProgressionHash;
+    using ProgressionHash = std::unordered_map<size_t, std::vector<size_t>>;
     mutable ProgressionHash m_progression;
 
-    typedef std::shared_ptr<OffTrackDetector> OffTrackDetectorPtr;
-    typedef std::vector<OffTrackDetectorPtr> OTDVector;
+    using OffTrackDetectorS = std::shared_ptr<OffTrackDetector>;
+    using OTDVector = std::vector<OffTrackDetectorS>;
     OTDVector m_offTrackDetectors;
 
     // Data structure to determine if a car is stuck.
     // In that case we move the car onto the previous check point.
-    typedef std::pair<TrackTilePtr, int> StuckTileCounter; // Tile pointer and counter.
-    typedef std::unordered_map<size_t, StuckTileCounter> StuckHash; // Car index to StuckTileCounter.
+    using StuckTileCounter = std::pair<TrackTileS, int>; // Tile pointer and counter.
+    using StuckHash = std::unordered_map<size_t, StuckTileCounter>; // Car index to StuckTileCounter.
     StuckHash m_stuckHash;
 
     struct CarStatus
     {
         size_t currentTargetNodeIndex = 0;
-
         size_t nextTargetNodeIndex = 0;
-
         size_t prevTargetNodeIndex = 0;
 
         size_t routeProgression = 0;
 
         size_t position = 0;
     };
-    typedef std::unordered_map<size_t, CarStatus> StatusHash; // Car index to CarStatus.
+    using StatusHash = std::unordered_map<size_t, CarStatus>; // Car index to CarStatus.
     StatusHash m_statusHash;
 
     const size_t m_numCars;
 
     size_t m_lapCount;
 
-    Timing m_timing;
+    using TimingS = std::shared_ptr<Timing>;
+    TimingS m_timing;
+    TrackS m_track;
 
-    std::shared_ptr<Track> m_track;
+    bool m_started = false;
+    bool m_checkeredFlagEnabled = false;
+    bool m_winnerFinished = false;
+    bool m_isfinishedSignalSent = false;
 
-    bool m_started;
-
-    bool m_checkeredFlagEnabled;
-
-    bool m_winnerFinished;
-
-    bool m_isfinishedSignalSent;
-
-    int m_bestPos;
+    std::optional<size_t> m_bestPos;
 
     QTimer m_offTrackMessageTimer;
 
-    int m_offTrackCounter;
+    int m_offTrackCounter = 0;
 
     Game & m_game;
 };
