@@ -34,7 +34,7 @@ Startlights::Startlights()
     m_timer.setInterval(1000 / m_stepsPerState);
 }
 
-bool Startlights::timeElapsed(size_t limit)
+bool Startlights::timeElapsed(int limit)
 {
     if (++m_counter > limit)
     {
@@ -55,7 +55,7 @@ void Startlights::beginAnimation()
     m_timer.start();
 }
 
-void Startlights::setDimensions(size_t width, size_t height)
+void Startlights::setDimensions(int width, int height)
 {
     m_width = width;
     m_height = height;
@@ -78,7 +78,7 @@ float Startlights::glowScale() const
 
 void Startlights::stateInit()
 {
-    const size_t second = m_stepsPerState;
+    const int second = m_stepsPerState;
 
     m_pos = MCVector3dF(m_width / 2, 3 * m_height / 2, 0);
     m_animation.init(
@@ -93,10 +93,9 @@ void Startlights::stateInit()
 
 void Startlights::stateAppear()
 {
-    const size_t second = m_stepsPerState;
-
     m_animation.update();
-    if (timeElapsed(second))
+
+    if (const int second = m_stepsPerState; timeElapsed(second))
     {
         m_state = State::FirstRow;
         emit messageRequested("3");
@@ -105,9 +104,7 @@ void Startlights::stateAppear()
 
 void Startlights::stateFirstRow()
 {
-    const size_t second = m_stepsPerState;
-
-    if (timeElapsed(second))
+    if (const int second = m_stepsPerState; timeElapsed(second))
     {
         m_state = State::SecondRow;
         emit messageRequested("2");
@@ -116,9 +113,7 @@ void Startlights::stateFirstRow()
 
 void Startlights::stateSecondRow()
 {
-    const size_t second = m_stepsPerState;
-
-    if (timeElapsed(second))
+    if (const int second = m_stepsPerState; timeElapsed(second))
     {
         m_state = State::ThirdRow;
         emit messageRequested("1");
@@ -127,9 +122,7 @@ void Startlights::stateSecondRow()
 
 void Startlights::stateThirdRow()
 {
-    const size_t second = m_stepsPerState;
-
-    if (timeElapsed(second))
+    if (const int second = m_stepsPerState; timeElapsed(second))
     {
         m_state = State::Go;
         emit messageRequested(QObject::tr("GO!!!"));
@@ -140,9 +133,7 @@ void Startlights::stateThirdRow()
 
 void Startlights::stateGo()
 {
-    const size_t second = m_stepsPerState;
-
-    if (timeElapsed(second))
+    if (const int second = m_stepsPerState; timeElapsed(second))
     {
         m_state = State::Disappear;
         m_animation.init(
