@@ -17,10 +17,12 @@
 #define TIMING_HPP
 
 #include <QObject>
+
+#include <chrono>
 #include <string>
 #include <vector>
 
-class Car;
+using namespace std::chrono_literals;
 
 class Timing : public QObject
 {
@@ -51,11 +53,8 @@ public:
     //! \return the lap for the leading car.
     size_t leadersLap() const;
 
-    //! \return the race time in msecs.
-    int raceTime() const;
-
-    //! \return the race time of given car in msecs.
-    int raceTime(size_t index) const;
+    std::chrono::milliseconds raceTime() const;
+    std::chrono::milliseconds raceTime(size_t index) const;
 
     /*! \return the record race time for the given car in msecs or
      *  -1 if invalid car or time not set. */
@@ -85,17 +84,11 @@ public:
     //! Set the current race record.
     void setRaceRecord(int msecs);
 
-    //! Starts the timing.
     void start();
-
-    //! Stops the timing.
     void stop();
-
-    //! Resets the timing.
     void reset();
 
-    //! Increase timer assuming 60 Hz update rate
-    void tick();
+    void tick(std::chrono::milliseconds timeStep);
 
     //! Converts msecs to string "mm:ss.zz".
     static std::wstring msecsToString(int msec);
@@ -105,7 +98,6 @@ signals:
     void lapCompleted(size_t index, int msec);
 
     void lapRecordAchieved(int msec);
-
     void raceRecordAchieved(int msec);
 
 private:
@@ -113,11 +105,9 @@ private:
     struct Times
     {
         int lastLapTime = -1;
-
         int recordLapTime = -1; // Personal best
 
-        int raceTime = 0;
-
+        std::chrono::milliseconds raceTime = 0ms;
         int recordRaceTime = 0; // Personal best
 
         size_t lap = 0;
@@ -128,13 +118,11 @@ private:
     };
 
     std::vector<Timing::Times> m_times;
-
-    int m_time;
+    std::chrono::milliseconds m_time;
 
     bool m_started;
 
     int m_lapRecord;
-
     int m_raceRecord;
 };
 
